@@ -4,7 +4,7 @@
 """
 import numpy as np
 from H_MCRLLM import *
-import H_MCRLLM.preprocessing as preprocessing
+from H_MCRLLM.preprocessing import preprocess_data
 
 class h_MCR_LLM:
     
